@@ -4,8 +4,7 @@
 #                                                                                 
 #    This program is free software; you can redistribute it and/or modify         
 #    it under the terms of the GNU General Public License as published by         
-#    the Free Software Foundation; either version 2 of the License, or            
-#    (at your option) any later version.                                          
+#    the Free Software Foundation, version 2.                                      
 #                                                                                 
 #    This program is distributed in the hope that it will be useful,              
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of               
@@ -41,16 +40,17 @@ try:
 except ImportError:
     CustomizationPolicy = None
 
-from Globals import package_home
-from Products.CMFCore import utils as cmfutils
-from Products.CMFCore import permissions
-from Products.CMFCore import DirectoryView
-from Products.CMFPlone.utils import ToolInit
-from Products.Archetypes.atapi import *
-from Products.Archetypes import listTypes
-from Products.Archetypes.utils import capitalize
-from zope.i18nmessageid import MessageFactory
 from AccessControl import allow_module
+from Globals import package_home
+from Products.Archetypes import listTypes
+from Products.Archetypes.atapi import *
+from Products.Archetypes.utils import capitalize
+from Products.CMFCore import DirectoryView
+from Products.CMFCore import permissions
+from Products.CMFCore import utils as cmfutils
+from Products.CMFPlone.utils import ToolInit
+from zope.i18nmessageid import MessageFactory
+import utilities
 
 ZipFileTransportMessageFactory = MessageFactory('ZipFileTransport')
 allow_module('collective.zipfiletransport.ZipFileTransportMessageFactory')
@@ -59,9 +59,6 @@ import os, os.path
 
 from collective.zipfiletransport.config import *
 
-DirectoryView.registerDirectory('skins', product_globals)
-DirectoryView.registerDirectory('skins/ZipFileTransport',
-                                    product_globals)
 
 
 def initialize(context):
@@ -83,3 +80,4 @@ def initialize(context):
         CustomizationPolicy.register(context)
         print 'Customization policy for ZipFileTransport installed'
 
+
