@@ -1,10 +1,10 @@
 ##################################################################################
-#    Copyright (C) 2006-2007 Utah State University, All rights reserved.          
+#    Copyright (c) 2004-2009 Utah State University, All rights reserved. 
+#    Portions copyright 2009 Massachusetts Institute of Technology, All rights reserved.
 #                                                                                 
 #    This program is free software; you can redistribute it and/or modify         
 #    it under the terms of the GNU General Public License as published by         
-#    the Free Software Foundation; either version 2 of the License, or            
-#    (at your option) any later version.                                          
+#    the Free Software Foundation, version 2.                                      
 #                                                                                 
 #    This program is distributed in the hope that it will be useful,              
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of               
@@ -17,10 +17,8 @@
 #                                                                                 
 ##################################################################################
 
-__author__ = 'Brent Lambert, David Ray, Jon Thomas'
-__docformat__ = 'restructuredtext'
-__version__ = "$Revision: 1 $"[11:-2]
-
+__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
+__version__   = '$ Revision 0.0 $'[11:-2]
 
 from zope.interface import Interface
 
@@ -75,7 +73,7 @@ class IZipFileTransportUtility(Interface):
         """
         
     def _getAllObjectsData(self, objects_listing, context_path):
-        """ Get all of the Object """
+        """ Get the path to a file containing all object data """
     
     def _objImplementsInterface(self, obj, interfaceClass):
         """
@@ -101,3 +99,14 @@ class IZipFileTransportUtility(Interface):
     
     def getZipFile(self, zfile, filename):
          """ Gets a file from the Zip archive."""
+
+
+class IZipFileAdapter(Interface):
+    """ Marker interface for export adapter. """
+
+    def writeObjectToZipArchive(context, zipfile, comments):
+        """ Write an object to the Zip archive. """
+
+    def readObjectFromZipArchive(zipfile):
+        """ Read object data from Zip archive. """
+
